# SPDX-FileCopyrightText: 2023-2024 Simon Bruder <simon@sbruder.de>
#
# SPDX-License-Identifier: AGPL-3.0-or-later

{ config, lib, pkgs, modulesPath, ... }:

{
  imports = [
    (modulesPath + "/profiles/qemu-guest.nix")
  ];

  sbruder.machine.isVm = true;

  boot = {
    initrd = {
      availableKernelModules = [ "xhci_pci" "virtio_pci" "usbhid" "sr_mod" ];
    };
    loader = {
      grub.enable = false;
      systemd-boot.enable = true;
      efi.canTouchEfiVariables = true;
    };
  };

  fileSystems = {
    "/" = {
      device = "/dev/disk/by-uuid/c39bdb61-2e4c-464b-8c4c-bb6bb7f342a2";
      fsType = "btrfs";
      options = [ "compress=zstd" ];
    };
    "/boot" = {
      device = "/dev/disk/by-uuid/D976-BBAF";
      fsType = "vfat";
    };
  };

  networking.useDHCP = false;
  networking.usePredictableInterfaceNames = false;
  systemd.network = {
    enable = true;
    networks = {
      eth0 = {
        name = "eth0";
        DHCP = "yes";
        domains = [ "salespointframework.org" ];
        address = [ "2a01:4f9:c011:9c01::1/64" ];
        gateway = [ "fe80::1" ];
      };
    };
  };

  # no smart on qemu disk
  services.smartd.enable = false;
}
